

set -ex



test -f $PREFIX/include/brunsli/encode.h
test -f $PREFIX/include/brunsli/decode.h
test -f $PREFIX/lib/libbrunslienc-c${SHLIB_EXT}
test -f $PREFIX/lib/libbrunslidec-c${SHLIB_EXT}
which cbrunsli
which dbrunsli
exit 0
